[GOLD][COMMITTED] Fix build breakage due to -Wshadow.

Doug Kwan (關振德) dougkwan@google.com
Sat Dec 12 01:29:00 GMT 2009


Hi,

    I just committed this patch.  The -Wshadow option broke gold.

-Doug

2009-12-11  Doug Kwan  <dougkwan@google.com>

        * arm.cc (Target_arm::do_finalize_sections): Fix build breakage
        due to -Wshadow.
        * attributes.cc (Object_attribute::size): Ditto.
        (Attributes_section_data::size): Ditto.
        (Attributes_section_data::Attributes_section_data): Ditto.
        (Output_attributes_section_data::do_write): Ditto.
        * attributes.h (Object_attribute::set_type): Ditto.
        * testsuite/tls_test_main.cc (safe_lock, safe_unlock): Ditto.
-------------- next part --------------
Index: gold/arm.cc
===================================================================
RCS file: /cvs/src/src/gold/arm.cc,v
retrieving revision 1.41
diff -u -p -r1.41 arm.cc
--- gold/arm.cc	11 Dec 2009 13:42:12 -0000	1.41
+++ gold/arm.cc	12 Dec 2009 01:19:09 -0000
@@ -4784,11 +4784,10 @@ Target_arm<big_endian>::do_finalize_sect
     }
 
   // Create an .ARM.attributes section if there is not one already.
-  Output_attributes_section_data* attributes_section =
+  Output_attributes_section_data* as =
     new Output_attributes_section_data(*this->attributes_section_data_);
-  layout->add_output_section_data(".ARM.attributes",
-				  elfcpp::SHT_ARM_ATTRIBUTES, 0,
-				  attributes_section, false);
+  alayout->add_output_section_data(".ARM.attributes",
+				   elfcpp::SHT_ARM_ATTRIBUTES, 0, as, false);
 }
 
 // Return whether a direct absolute static relocation needs to be applied.
Index: gold/attributes.h
===================================================================
RCS file: /cvs/src/src/gold/attributes.h,v
retrieving revision 1.1
diff -u -p -r1.1 attributes.h
--- gold/attributes.h	9 Dec 2009 03:02:28 -0000	1.1
+++ gold/attributes.h	12 Dec 2009 01:19:09 -0000
@@ -103,8 +103,8 @@ class Object_attribute
 
   // Set attribute type.
   void
-  set_type(int type)
-  { this->type_ = type; }
+  set_type(int at)
+  { this->type_ = at; }
 
   // Return integer value.
   unsigned int
Index: gold/testsuite/tls_test_main.cc
===================================================================
RCS file: /cvs/src/src/gold/testsuite/tls_test_main.cc,v
retrieving revision 1.7
diff -u -p -r1.7 tls_test_main.cc
--- gold/testsuite/tls_test_main.cc	15 Aug 2008 04:57:46 -0000	1.7
+++ gold/testsuite/tls_test_main.cc	12 Dec 2009 01:19:09 -0000
@@ -33,16 +33,16 @@
 #define safe_lock(muptr)			\
   do						\
     {						\
-      int err = pthread_mutex_lock(muptr);	\
-      assert(err == 0);				\
+      int pthread_err = pthread_mutex_lock(muptr);	\
+      assert(pthread_err == 0);				\
     }						\
   while (0)
 
 #define safe_unlock(muptr)			\
   do						\
     {						\
-      int err = pthread_mutex_unlock(muptr);	\
-      assert(err == 0);				\
+      int pthread_err = pthread_mutex_unlock(muptr);	\
+      assert(pthread_err == 0);				\
     }						\
   while (0)
 


More information about the Binutils mailing list
Index: gold/attributes.cc
===================================================================
RCS file: /cvs/src/src/gold/attributes.cc,v
retrieving revision 1.1
diff -u -p -r1.1 attributes.cc
--- gold/attributes.cc	9 Dec 2009 03:02:28 -0000	1.1
+++ gold/attributes.cc	12 Dec 2009 01:19:09 -0000
@@ -45,12 +45,12 @@ Object_attribute::size(int tag) const
   if (this->is_default_attribute())
     return 0;
 
-  size_t size = get_length_as_unsigned_LEB_128(tag);
+  size_t uleb128_size = get_length_as_unsigned_LEB_128(tag);
   if (Object_attribute::attribute_type_has_int_value(this->type_))
-    size += get_length_as_unsigned_LEB_128(this->int_value_);
+    uleb128_size += get_length_as_unsigned_LEB_128(this->int_value_);
   if (Object_attribute::attribute_type_has_string_value(this->type_))
-    size += this->string_value_.size() + 1;
-  return size;
+    uleb128_size += this->string_value_.size() + 1;
+  return uleb128_size;
 }
 
 // Whether this has the default value (0/"").
@@ -266,11 +266,11 @@ Attributes_section_data::size() const
 }
 
 // Construct an Attributes_section_data object by parsing section contents
 // specified by VIEW and SIZE.
 
 Attributes_section_data::Attributes_section_data(
     const unsigned char* view,
-    section_size_type size)
+    section_size_type view_size)
 {
   for (int vendor = OBJ_ATTR_FIRST; vendor <= OBJ_ATTR_LAST; ++vendor)
     this->vendor_object_attributes_[vendor] =
@@ -280,16 +280,16 @@ Attributes_section_data::Attributes_sect
   p = view;
   if (*(p++) == 'A')
     {
-      size--;
-      while (size > 0)
+      view_size--;
+      while (view_size > 0)
 	{
 	  // Size of vendor attributes section.
 	  section_size_type section_size =
 	    convert_to_section_size_type(read_from_pointer<32>(&p));
 
-	  if (section_size > size)
-	    section_size = size;
-	  size -= section_size;
+	  if (section_size > view_size)
+	    section_size = view_size;
+	  view_size -= section_size;
 
 	  const char* section_name = reinterpret_cast<const char*>(p);
 	  section_size_type section_name_size = strlen(section_name) + 1;
@@ -443,10 +443,9 @@ Attributes_section_data::write(std::vect
 void
 Output_attributes_section_data::do_write(Output_file* of)
 {
-  off_t offset = this->offset();
   const section_size_type oview_size =
     convert_to_section_size_type(this->data_size());
-  unsigned char* const oview = of->get_output_view(offset, oview_size);
+  unsigned char* const oview = of->get_output_view(this->offset(), oview_size);
 
   std::vector<unsigned char> buffer;
   this->attributes_section_data_.write(&buffer);
@@ -266,11 +266,11 @@ Attributes_section_data::size() const
 
 // Construct an Attributes_section_data object by parsing section contents
-// specified by VIEW and SIZE.
+// specified by VIEW and VIEW_SIZE.
 
 Attributes_section_data::Attributes_section_data(